@@ -12,7 +12,7 @@ from tornado.httpclient import AsyncHTTPClient
 from holmes.handlers.worker import WorkerHandler, WorkersHandler, WorkersInfoHandler
 from holmes.handlers.worker_state import WorkerStateHandler
 from holmes.handlers.page import (
-    PageHandler, PagesHandler, PageReviewsHandler, PageViolationsPerDayHandler
+    PageHandler, PageReviewsHandler, PageViolationsPerDayHandler
 )
 from holmes.handlers.violation import (
     MostCommonViolationsHandler, ViolationsHandler, ViolationHandler
@@ -23,7 +23,7 @@ from holmes.handlers.review import (
 from holmes.handlers.next_job import NextJobHandler
 from holmes.handlers.domains import (
     DomainsHandler, DomainDetailsHandler, DomainViolationsPerDayHandler,
-    DomainReviewsHandler
+    DomainReviewsHandler, DomainsChangeStatusHandler
 )
 from holmes.handlers.search import (
     SearchHandler
@@ -36,6 +36,7 @@ from holmes.handlers.bus import EventBusHandler
 from holmes.event_bus import EventBus, NoOpEventBus
 from holmes.utils import load_classes
 from holmes.models import Key
+from holmes.models import KeysCategory
 from holmes.cache import Cache
 
 
@@ -73,11 +74,11 @@ class HolmesApiServer(Server):
             (r'/page/([a-z0-9-]*)/?', PageHandler),
             (r'/search/?', SearchHandler),
             (r'/page/?', PageHandler),
-            (r'/pages/?', PagesHandler),
             (r'/domains/?', DomainsHandler),
             (r'/domains/([^/]+)/?', DomainDetailsHandler),
             (r'/domains/([^/]+)/violations-per-day/?', DomainViolationsPerDayHandler),
             (r'/domains/([^/]+)/reviews/?', DomainReviewsHandler),
+            (r'/domains/([^/]+)/change-status/?', DomainsChangeStatusHandler),
             (r'/next/?', NextJobHandler),
             (r'/events/?', EventBusHandler),
             (r'/violations/?', ViolationsHandler),
@@ -126,10 +127,23 @@ class HolmesApiServer(Server):
 
         self.application.cache = Cache(self.application)
 
+    def _insert_key_category(self, key, name):
+        category = KeysCategory.get_or_create(self.application.db, name)
+        self.application.db.add(category)
+        self.application.db.flush()
+        self.application.db.commit()
+        return category
+
     def _insert_keys(self, keys):
         for name in keys.keys():
             key = Key.get_or_create(self.application.db, name)
             keys[name]['key'] = key
+
+            category_name = keys[name].get('category', None)
+            if category_name:
+                category = self._insert_key_category(key, category_name)
+                key.category = category
+
             self.application.db.add(key)
             self.application.db.flush()
             self.application.db.commit()
